import React, { useEffect, RefObject } from 'react';
import * as d3 from 'd3';

const BarChart = () => {
    const ref: RefObject<HTMLDivElement> = React.createRef();

    const dataShow = [
        { Country: "Russia", Value: 420000 },
        { Country: "France", Value: 190000 },
        { Country: "United-State", Value: 330000 },
        { Country: "Brazil", Value: 280000 },
        { Country: "Germany", Value: 200000 },
        { Country: "United-Kingdom", Value: 150000 },
        { Country: "China", Value: 350000 }
    ];

    useEffect(() => {
        draw();
    });

    const draw = () => {
        const container = ref.current;
        if (!container) return;

        var margin = { top: 30, right: 30, bottom: 70, left: 60 },
                    width = 460 - margin.left - margin.right,
                    height = 400 - margin.top - margin.bottom;

        var svg = d3.select(container)
                    .append("svg")
                    .attr("width", width + margin.left + margin.right)
                    .attr("height", height + margin.top + margin.bottom)
                    .append("g")
                    .attr("transform", "translate(" + margin.left + "," + margin.top + ")");

        // X axis
        var x = d3.scaleBand()
                .range([0, width])
                .domain(
                    dataShow.map(function (d) {
                    return d.Country;
                    })
                )
                .padding(0.2);

        svg.append("g")
            .attr("transform", "translate(0," + height + ")")
            .call(d3.axisBottom(x))
            .selectAll("text")
            .attr("transform", "translate(-10,0)rotate(-45)")
            .style("text-anchor", "end");

        // Y axis
        var y = d3.scaleLinear().domain([0, 500000]).range([height, 0]);

        svg.append("g").call(d3.axisLeft(y));

        // Data
        svg.selectAll(".block")
            .data(dataShow)
            .enter()
            .append("rect")
            .attr("class", "bar")
            .attr("x", function (d: any) {
                return x(d.Country);
            })
            .attr("width", x.bandwidth())
            .attr("y", function (d: any) {
                return y(d.Value);
            })
            .attr("height", function (d: any) {
                return height - y(d.Value);
            })
            .attr("fill", "#69b3a2");
    }

    return (
        <div className="BarChart" ref={ref}></div>
    );
}

export default BarChart;